<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:include href="_common.xsl"/>
  <xsl:include href="_dependencies.xsl"/>

  <!-- Type of object for header -->
  <xsl:variable name="objectType" select="'Object'"/>
  
  <!-- Path for object -->
  <xsl:variable name="objectPath" select="'Objects'"/>

  <!-- Root -->
  <xsl:template match="/DataDocumenter">
    <xsl:variable name="pathPart" select="Breadcrumbs/Breadcrumb[last()]/@src"/>
      <div data-page="{$pathPart}{$ext}">
        <div class="container">
        <xsl:apply-templates select="Breadcrumbs"/>
        <xsl:apply-templates select="Table | View"/>

        <xsl:call-template name="applyDependenciesEvents"/>
    </div>
    </div>
  </xsl:template>

  <!-- Object information for table or view -->
  <xsl:template match="Table | View">
    <xsl:call-template name="objectInformation">
      <xsl:with-param name="objectType" select="$objectType"/>
    </xsl:call-template>

    <xsl:apply-templates select="Columns"/>
    <xsl:apply-templates select="Relations"/>
    <xsl:apply-templates select="UniqueKeys"/>
    <xsl:apply-templates select="Triggers"/>
    <xsl:apply-templates select="Dependencies"/>
    <xsl:apply-templates select="Script"/>

    <xsl:call-template name="metadata"/>
  </xsl:template>

  <!-- Columns -->
  <xsl:template match="Columns">
    <xsl:choose>
      <xsl:when test="./*">
        <div class="collapsible" data-key="columns">
          <div class="collapsible-link font-large font-bold">Columns</div>
          <div class="collapsible-area">
            <table class="table">
          <thead>
            <tr>
              <th style="width: 40px !important"></th>
              <th style="width: 40px !important">Key</th>
              <th>Name</th>
              <th style="width: 170px">Data type</th>
              <th style="width: 15px !important">Null</th>
              <th class="only-desktop">Attributes</th>
              <th class="only-desktop">References</th>
              <th class="only-desktop">Description</th>

              <xsl:call-template name="customFieldColumnsHeaders"/>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="Column"/>
          </tbody>
        </table>
          </div>
        </div>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Column -->
  <xsl:template match="Column">
    <tr>
      <td>
        <xsl:value-of select="OrdinalPosition"/>
      </td>

      <xsl:choose>
        <xsl:when test="UniqueConstraintType = 'PK'">
          <td>
            <i class="icon-key no-margin" title="Primary key"></i>
          </td>
        </xsl:when>
        <xsl:when test="UniqueConstraintType = 'DisabledPK'">
          <td>
            <i class="icon-primary-key-disabled no-margin" title="Disabled primary key"></i>
          </td>
        </xsl:when>
        <xsl:when test="UniqueConstraintType = 'UserDefinedPK'">
          <td>
            <i class="icon-user-key no-margin" title="User-defined primary key"></i>
          </td>
        </xsl:when>
        <!--<xsl:when test="UniqueConstraintType = 'DeletedPK'">
          <td>
            <i class="icon-key no-margin" title="Deleted primary key"></i>
          </td>
        </xsl:when>-->
        <xsl:when test="UniqueConstraintType = 'UK'">
          <td>
            <i class="icon-unique-key no-margin" title="Unique key"></i>
          </td>
        </xsl:when>
        <xsl:when test="UniqueConstraintType = 'DisabledUK'">
          <td>
            <i class="icon-unique-key-disabled no-margin" title="Disabled unique key"></i>
          </td>
        </xsl:when>
        <xsl:when test="UniqueConstraintType = 'UserDefinedUK'">
          <td>
            <i class="icon-user-unique-key no-margin" title="User-defined unique key"></i>
          </td>
        </xsl:when>
        <!--<xsl:when test="UniqueConstraintType = 'DeletedUK'">
          <td>
            <i class="icon-key no-margin" title="Deleted unique key"></i>
          </td>
        </xsl:when>-->
        <xsl:otherwise>
          <td></td>
        </xsl:otherwise>
      </xsl:choose>

      <td>
        <xsl:value-of select="Name"/>
        <xsl:if test="string-length(Title)>0">
          (<xsl:value-of select="Title"/>)
        </xsl:if>
      </td>
      <td>
        <xsl:value-of select="DataType"/>
      </td>
      <td>
        <xsl:if test="IsNullable = 'true'">
            <i class="icon-check no-margin" title="Nullable"></i>
        </xsl:if>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="columnAttributes"/>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="columnReferences">
          <xsl:with-param name="separator" select="'&lt;br&gt;'"/>
        </xsl:call-template>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>

      <xsl:call-template name="customFieldColumnsData"/>
    </tr>

    <xsl:if test="string-length(Description)>0
        or IsIdentity = 'true'
        or string-length(DefaultValue)>0
        or (IsComputed = 'true' and string-length(ComputedFormula)>0)
        or References/*
        or CustomFields/Data/CustomField/*">
      <tr class="only-mobile">
        <td colspan="5">
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>

          <xsl:if test="string-length(Description)>0
              and (IsIdentity = 'true'
                or string-length(DefaultValue)>0
                or (IsComputed = 'true' and string-length(ComputedFormula)>0))">
            <br></br>
          </xsl:if>

          <xsl:call-template name="columnAttributes"/>

          <xsl:if test="(string-length(Description)>0
              or (IsIdentity = 'true'
                or string-length(DefaultValue)>0
                or (IsComputed = 'true' and string-length(ComputedFormula)>0)))
              and References/*">
            <br></br>
          </xsl:if>

          <xsl:if test="References/*">
            References:
            <xsl:call-template name="columnReferences">
              <xsl:with-param name="separator" select="' ,'"/>
            </xsl:call-template>
          </xsl:if>

          <xsl:if test="(string-length(Description)>0
              or (IsIdentity = 'true'
                or string-length(DefaultValue)>0
                or (IsComputed = 'true' and string-length(ComputedFormula)>0)))
              or References/*
              and CustomFields/Data/CustomField/*">
            <br></br>
          </xsl:if>

          <xsl:call-template name="customFieldColumnsText"/>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <!-- Column References -->
  <xsl:template name="columnReferences">
    <xsl:param name="separator" />

    <xsl:for-each select="References/Reference">
      <xsl:call-template name="linkToObject">
        <xsl:with-param name="isSameObject" select="IsSameObject"/>
        <xsl:with-param name="isExported" select="IsExported"/>
        <xsl:with-param name="documentation" select="ObjectDatabaseIdString"/>
        <xsl:with-param name="objectId" select="ObjectIdString"/>
        <xsl:with-param name="objectName" select="ReferenceString"/>
        <xsl:with-param name="objectTitle" select="''"/>
      </xsl:call-template>

      <xsl:if test="position() != last()">
        <xsl:value-of select="$separator" disable-output-escaping="yes"/>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

  <!-- Column Attributes -->
  <xsl:template name="columnAttributes">
    <xsl:if test="IsIdentity = 'true'">
      Identity / Auto increment column
      
      <xsl:if test="string-length(DefaultValue)>0 or (IsComputed = 'true' and string-length(ComputedFormula)>0)">
        <br/>
      </xsl:if>
    </xsl:if>
    <xsl:if test="string-length(DefaultValue)>0">
      Default:
      <xsl:call-template name="insertHtmlNewLines">
        <xsl:with-param name="value" select="DefaultValue"/>
      </xsl:call-template>
      
      <xsl:if test="IsComputed = 'true' and string-length(ComputedFormula)>0">
        <br/>
      </xsl:if>
    </xsl:if>
    <xsl:if test="IsComputed = 'true' and string-length(ComputedFormula)>0">
      Computed:
      <xsl:call-template name="insertHtmlNewLines">
        <xsl:with-param name="value" select="ComputedFormula"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <!-- Relations -->
  <xsl:template match="Relations">
    <xsl:choose>
      <xsl:when test="./* and (RelationsTo/* or RelationsFrom/*)">
        <div class="collapsible" data-key="relations">
          <div class="collapsible-link font-large font-bold">Relations</div>
          <div class="collapsible-area">
            <table class="table">
          <thead>
            <tr>
              <th>Foreign table</th>
              <th style="width: 40px !important"></th>
              <th>Primary table</th>
              <th class="only-desktop">Join</th>
              <th class="only-desktop">Title / Name / Description</th>

              <xsl:call-template name="customFieldColumnsHeaders"/>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="RelationsFrom/Relation"/>
            <xsl:apply-templates select="RelationsTo/Relation"/>
          </tbody>
        </table>
          </div>
        </div>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Relation to -->
  <xsl:template match="RelationsTo/Relation">
    <tr>
      <td>
        <xsl:call-template name="linkToObject">
          <xsl:with-param name="isSameObject" select="IsSameObject"/>
          <xsl:with-param name="isExported" select="IsExported"/>
          <xsl:with-param name="documentation" select="ObjectDatabaseIdString"/>
          <xsl:with-param name="objectId" select="ObjectIdString"/>
          <xsl:with-param name="objectName" select="ObjectFullName"/>
          <xsl:with-param name="objectTitle" select="ObjectTitle"/>
        </xsl:call-template>
      </td>
      
      <!-- relation icon -->
      <td>
        <xsl:choose>
          <xsl:when test="Type = 'USER'">
            <i class="icon-user-relation no-margin" title="User defined relation"></i>
          </xsl:when>
          <xsl:otherwise>
            <i class="icon-relation no-margin" title="Relation"></i>
          </xsl:otherwise>
        </xsl:choose>
      </td>

      <td>
        <xsl:choose>
          <xsl:when test="$objectType = 'Table'">
            <xsl:value-of select="/DataDocumenter/Table/ObjectName"/>
            <xsl:if test="string-length(/DataDocumenter/Table/Title)>0"> (<xsl:value-of select="/DataDocumenter/Table/Title"/>)</xsl:if>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="/DataDocumenter/View/ObjectName"/>
            <xsl:if test="string-length(/DataDocumenter/View/Title)>0"> (<xsl:value-of select="/DataDocumenter/View/Title"/>)</xsl:if>
          </xsl:otherwise>
        </xsl:choose>
      </td>
      <td class="only-desktop">
        <xsl:apply-templates select="Join/Condition"/>
      </td>
      <td class="only-desktop">
        <xsl:if test="string-length(Title)>0">
          <xsl:value-of select="Title"/>
          <br/>
        </xsl:if>
        
        <xsl:value-of select="Name"/>
        
        <xsl:if test="string-length(Description)>0">
          <br/>
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>
        </xsl:if>
      </td>

      <xsl:call-template name="customFieldColumnsData"/>
    </tr>

    <tr class="only-mobile">
      <td colspan="3">
        <div>
          <xsl:apply-templates select="Join/Condition"/>
        </div>

        <xsl:if test="string-length(Title)>0">
          <xsl:value-of select="Title"/>
          <br/>
        </xsl:if>
        
        <xsl:value-of select="Name"/>
        
        <xsl:if test="string-length(Description)>0">
          <br/>
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="(string-length(Name)>0
              or string-length(Description)>0)
              and CustomFields/Data/CustomField/*">
          <br></br>
        </xsl:if>

        <xsl:call-template name="customFieldColumnsText"/>
      </td>
    </tr>
  </xsl:template>

  <!-- Relation to join condition -->
  <xsl:template match="RelationsTo/Relation/Join/Condition">
    <xsl:choose>
      <xsl:when test="IsSameObject='No'">
        <xsl:value-of select="OtherObjectName"/>
      </xsl:when>
      <xsl:otherwise>
        <span style="font-weight: bold">
          <xsl:value-of select="OtherObjectName"/>
        </span>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>.</xsl:text>
    <xsl:value-of select="OtherColumn"/>
    
    <xsl:text> = </xsl:text>
    
    <span style="font-weight: bold">
      <xsl:choose>
        <xsl:when test="$objectType = 'Table'">
          <xsl:value-of select="/DataDocumenter/Table/ObjectName"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="/DataDocumenter/View/ObjectName"/>
        </xsl:otherwise>
      </xsl:choose>
    </span>
    <xsl:text>.</xsl:text>
    <xsl:value-of select="CurrentColumn"/>
    <xsl:if test="position() != last()">
      <br/>
    </xsl:if>
  </xsl:template>

  <!-- Relation from -->
  <xsl:template match="RelationsFrom/Relation">
    <tr>
      <td>
        <xsl:choose>
          <xsl:when test="$objectType = 'Table'">
            <xsl:value-of select="/DataDocumenter/Table/ObjectName"/>
            <xsl:if test="string-length(/DataDocumenter/Table/Title)>0"> (<xsl:value-of select="/DataDocumenter/Table/Title"/>)</xsl:if>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="/DataDocumenter/View/ObjectName"/>
            <xsl:if test="string-length(/DataDocumenter/View/Title)>0"> (<xsl:value-of select="/DataDocumenter/View/Title"/>)</xsl:if>
          </xsl:otherwise>
        </xsl:choose>
      </td>

      <!-- relation icon -->
      <td>
        <xsl:choose>
          <xsl:when test="Type = 'USER'">
            <i class="icon-user-relation no-margin" title="User defined relation"></i>
          </xsl:when>
          <xsl:otherwise>
            <i class="icon-relation no-margin" title="Relation"></i>
          </xsl:otherwise>
        </xsl:choose>
      </td>

      <td>
        <xsl:call-template name="linkToObject">
          <xsl:with-param name="isSameObject" select="IsSameObject"/>
          <xsl:with-param name="isExported" select="IsExported"/>
          <xsl:with-param name="documentation" select="ObjectDatabaseIdString"/>
          <xsl:with-param name="objectId" select="ObjectIdString"/>
          <xsl:with-param name="objectName" select="ObjectFullName"/>
          <xsl:with-param name="objectTitle" select="ObjectTitle"/>
        </xsl:call-template>
      </td>
      <td class="only-desktop">
        <xsl:apply-templates select="Join/Condition"/>
      </td>
      <td class="only-desktop">
        <xsl:if test="string-length(Title)>0">
          <xsl:value-of select="Title"/>
          <br/>
        </xsl:if>
        
        <xsl:value-of select="Name"/>

        <xsl:if test="string-length(Description)>0">
          <br/>
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>
        </xsl:if>
      </td>

      <xsl:call-template name="customFieldColumnsData"/>
    </tr>

    <tr class="only-mobile">
      <td colspan="3">
        <div>
          <xsl:apply-templates select="Join/Condition"/>
        </div>

        <xsl:if test="string-length(Title)>0">
          <xsl:value-of select="Title"/>
          <br/>
        </xsl:if>
        
        <xsl:value-of select="Name"/>
        
        <xsl:if test="string-length(Description)>0">
          <br/>
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="(string-length(Name)>0
              or string-length(Description)>0)
              and CustomFields/Data/CustomField/*">
          <br></br>
        </xsl:if>

        <xsl:call-template name="customFieldColumnsText"/>
      </td>
    </tr>
  </xsl:template>

  <!-- Relation from join condition -->
  <xsl:template match="RelationsFrom/Relation/Join/Condition">
    <span style="font-weight: bold">
      <xsl:choose>
        <xsl:when test="$objectType = 'Table'">
          <xsl:value-of select="/DataDocumenter/Table/ObjectName"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="/DataDocumenter/View/ObjectName"/>
        </xsl:otherwise>
      </xsl:choose>
    </span>
    <xsl:text>.</xsl:text>
    <xsl:value-of select="CurrentColumn"/>
    
    <xsl:text> = </xsl:text>

    <xsl:choose>
      <xsl:when test="IsSameObject='No'">
        <xsl:value-of select="OtherObjectName"/>
      </xsl:when>
      <xsl:otherwise>
        <span style="font-weight: bold">
          <xsl:value-of select="OtherObjectName"/>
        </span>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>.</xsl:text>
    <xsl:value-of select="OtherColumn"/>
    
    <xsl:if test="position() != last()">
      <br/>
    </xsl:if>
  </xsl:template>

  <!-- Unique keys -->
  <xsl:template match="UniqueKeys">
    <xsl:choose>
      <xsl:when test="./*">
        <div class="collapsible" data-key="unique-keys">
          <div class="collapsible-link font-large font-bold">Unique keys</div>
          <div class="collapsible-area">
            <table class="table">
          <thead>
            <tr>
              <th style="width: 40px !important"></th>
              <th style="width: 20%">Key name</th>
              <th style="width: 20%">Columns</th>
              <th class="only-desktop">Description</th>

              <xsl:call-template name="customFieldColumnsHeaders"/>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="UniqueKey"/>
          </tbody>
        </table>
          </div>
        </div>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Unique key -->
  <xsl:template match="UniqueKey">
    <tr>
      <xsl:choose>
        <xsl:when test="Type = 'PK'">
          <td>
            <i class="icon-key no-margin" title="Primary key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'DisabledPK'">
          <td>
            <i class="icon-primary-key-disabled no-margin" title="Disabled primary key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'UserDefinedPK'">
          <td>
            <i class="icon-user-key no-margin" title="User-defined primary key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'UK'">
          <td>
            <i class="icon-unique-key no-margin" title="Unique key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'DisabledUK'">
          <td>
            <i class="icon-unique-key-disabled no-margin" title="Disabled unique key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'UserDefinedUK'">
          <td>
            <i class="icon-user-unique-key no-margin" title="User-defined unique key"></i>
          </td>
        </xsl:when>
        <xsl:otherwise>
          <td>
          </td>
        </xsl:otherwise>
      </xsl:choose>
      <td>
        <xsl:value-of select="Name"/>
      </td>
      <td>
        <xsl:value-of select="Columns"/>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>

      <xsl:call-template name="customFieldColumnsData"/>
    </tr>

    <xsl:if test="string-length(Description)>0">
      <tr class="only-mobile">
        <td colspan="3">
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>

          <xsl:if test="string-length(Description)>0
              and CustomFields/Data/CustomField/*">
            <br></br>
          </xsl:if>

          <xsl:call-template name="customFieldColumnsText"/>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <!-- Triggers -->
  <xsl:template match="Triggers">
    <xsl:choose>
      <xsl:when test="./*">
        <div class="collapsible" data-key="triggers">
          <div class="collapsible-link font-large font-bold">Triggers</div>
          <div class="collapsible-area">
            <table class="table">
          <thead>
            <tr>
              <th style="width: 40px !important"></th>
              <th style="width: 15%">Key name</th>
              <th style="width: 15%">When</th>
              <th class="only-desktop">Description</th>

              <!--<xsl:call-template name="customFieldColumnsHeaders"/>-->
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="Trigger"/>
          </tbody>
        </table>
          </div>
        </div>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Trigger -->
  <xsl:template match="Trigger">
    <tr class="dependency-node" data-node-id="{position()}">
      <xsl:choose>
        <xsl:when test="Type = 'ActiveTrigger'">
          <td style="white-space: nowrap;">
            <xsl:if test="Script and Script != ''">
              <span class="expand">
                <i class="icon-expand"></i>
              </span>
              <span class="collapse" style="display: none">
                <i class="icon-collapse"></i>
              </span>
            </xsl:if>

            <i class="icon-trigger-active no-margin" title="Active trigger"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'DisabledTrigger'">
          <td style="white-space: nowrap;">
            <xsl:if test="Script and Script != ''">
              <span class="expand">
                <i class="icon-expand"></i>
              </span>
              <span class="collapse" style="display: none">
                <i class="icon-collapse"></i>
              </span>
            </xsl:if>
            
            <i class="icon-trigger-disabled no-margin" title="Disabled trigger"></i>
          </td>
        </xsl:when>
        <xsl:otherwise>
          <td style="white-space: nowrap;">
           <xsl:if test="Script and Script != ''">
              <span class="expand">
                <i class="icon-expand"></i>
              </span>
              <span class="collapse" style="display: none">
                <i class="icon-collapse"></i>
              </span>
            </xsl:if>
          </td>
        </xsl:otherwise>
      </xsl:choose>
      <td>
        <xsl:value-of select="Name"/>
      </td>
      <td>
        <xsl:value-of select="When"/>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>

      <!--<xsl:call-template name="customFieldColumnsData"/>-->
    </tr>
    
    <!-- Trigger script -->
    <xsl:if test="Script and Script != ''">
      <tr data-parent-node-id="{position()}" style="display: none;" class="only-desktop">
        <td colspan="4">
          <div class="sql-script">
            <xsl:value-of select="Script" disable-output-escaping="yes"/>
          </div>
        </td>
      </tr>
    </xsl:if>

    <xsl:if test="string-length(Description)>0">
      <tr class="only-mobile">
        <td colspan="3">
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>

          <xsl:if test="string-length(Description)>0
              and CustomFields/Data/CustomField/*">
            <br></br>
          </xsl:if>

          <!--<xsl:call-template name="customFieldColumnsText"/>-->
        </td>
      </tr>

      <!-- Trigger script -->
      <xsl:if test="Script and Script != ''">
        <tr class="only-mobile">
          <td colspan="3">
            <div class="sql-script">
              <xsl:value-of select="Script" disable-output-escaping="yes"/>
            </div>
          </td>
        </tr>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <!-- Dependencies -->
  <xsl:template match="Dependencies">
    <xsl:apply-templates select="Uses">
      <xsl:with-param name="objectType" select="$objectType"/>
      <xsl:with-param name="content" select="$content"/>
      <xsl:with-param name="ext" select="$ext"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="UsedBy">
      <xsl:with-param name="objectType" select="$objectType"/>
      <xsl:with-param name="content" select="$content"/>
      <xsl:with-param name="ext" select="$ext"/>
    </xsl:apply-templates>
  </xsl:template>

  <!-- Script -->
  <xsl:template match="Script">
    <xsl:if test=". and . != ''">
      <div class="collapsible" data-key="script">
        <div class="collapsible-link font-large font-bold">Script</div>
        <div class="collapsible-area">
          <table class="table">
            <thead>
            </thead>
            <tbody>
              <tr>
                <td>
                  <xsl:value-of select="." disable-output-escaping="yes"/>
                </td>
              </tr>
            </tbody>
          </table>
        </div>
      </div>
    </xsl:if>
  </xsl:template>

  <!-- Link to object -->
  <xsl:template name="linkToObject">
    <xsl:param name="isSameObject" />
    <xsl:param name="isExported" />
    <xsl:param name="documentation" />
    <xsl:param name="objectId" />
    <xsl:param name="objectName" />
    <xsl:param name="objectTitle" />
      
    <xsl:choose>
      <xsl:when test="$isSameObject = 'No'
        and $isExported = 'Yes'
        and (($objectType = 'Table' and $objectId != /DataDocumenter/Table/ObjectId)
                or ($objectType = 'View' and $objectId != /DataDocumenter/View/ObjectId))">

        <xsl:choose>
          <xsl:when test="IsInCurrentModule='Yes'">

            <xsl:variable name="moduleObjectId">
              <xsl:choose>
                <xsl:when test="$objectType = 'Table'">
                  <xsl:value-of select="/DataDocumenter/Table/ModuleObjectId"/>
                </xsl:when>
                <xsl:when test="$objectType = 'View'">
                  <xsl:value-of select="/DataDocumenter/View/ModuleObjectId"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="''"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:variable>

            <xsl:choose>
              <xsl:when test="ObjectType = 'TABLE' and $moduleObjectId != ''">
                <a href="#{$root}/{$documentation}/modules/{$moduleObjectId}/tables/{$objectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="$objectName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'VIEW' and $moduleObjectId != ''">
                <a href="#{$root}/{$documentation}/modules/{$moduleObjectId}/views/{$objectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="$objectName"/>
                </a>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="$objectName"/>
              </xsl:otherwise>
            </xsl:choose>

          </xsl:when>
          <xsl:otherwise>

            <xsl:choose>
              <xsl:when test="ObjectType = 'TABLE'">
                <a href="#{$root}/{$documentation}/tables/{$objectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="$objectName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'VIEW'">
                <a href="#{$root}/{$documentation}/views/{$objectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="$objectName"/>
                </a>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="$objectName"/>
              </xsl:otherwise>
            </xsl:choose>

          </xsl:otherwise>
        </xsl:choose>

      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$objectName"/>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:if test="string-length($objectTitle)>0">
      (<xsl:value-of select="$objectTitle"/>)
    </xsl:if>
  </xsl:template>
</xsl:stylesheet>