<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:include href="_common.xsl"/>
    
    <xsl:output method="html" encoding="utf-8" doctype-system="about:legacy-compat"/>

    <!-- Default template -->
    <xsl:template match="*"></xsl:template>

    <!-- Redirection -->
    <xsl:template match="/DataDocumenter">
      <html>
          <head>
            <meta charset="utf-8"/>
            <meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
            <meta name="viewport" content="width=device-width, initial-scale=1"/>
            <title>
              <xsl:value-of select="Global/DocumentTitle"/>
              <xsl:text> – Dataedo</xsl:text>
            </title>

            <link href="{$resources}favicon.ico" rel="icon"/>
            <link href="{$resources}favicon.ico" rel="shortcut icon"/>
            <link rel="stylesheet" href="{$resources}lib/Google Fonts/style.css"/>
            <link rel="stylesheet" href="{$resources}lib/jQueryUI/jquery-ui-1.9.2.custom.min.css"/>
            <link rel="stylesheet" href="{$resources}css/reset.css"/>
            <link rel="stylesheet" href="{$resources}css/default.css"/>
            <link rel="stylesheet" href="{$resources}css/layout.css"/>
            <link rel="stylesheet" href="{$resources}css/inline-html.css"/>
            <link rel="stylesheet" href="{$resources}css/user.css"/>

            <!-- IE Fixes -->
            <xsl:comment>
              <![CDATA[[if lt IE 9]>
              <script src="{$resources}lib/HTML5shiv/html5shiv.js"></script>
              <![endif]]]>
            </xsl:comment>
          </head>
        
          <body class="font-size-medium">
            <div id="nav-toggle"></div>
            <xsl:call-template name="main"/>
            <xsl:call-template name="scripts"/>
          </body>
        </html>
    </xsl:template>

    <!-- Header -->
    <xsl:template name="header">
      <nav id="nav" class="grid">
          <div class="span12">
            <a href="#index" class="ajax logo" data-target="#right">
              <img src="{$resources}img/logo.png"/>
            </a>

            <div class="menu"></div>
            <h3 class="docname font-medium">
              <xsl:value-of select="/DataDocumenter/Global/DocumentTitle"/>
              <xsl:if test="/DataDocumenter/LicenseTag">
                <span class="trial trial-header"> Trial </span>
              </xsl:if>
          </h3>
          </div>
      </nav>
    </xsl:template>

    <!-- Content -->
    <xsl:template name="main">
      <div id="main" class="cf">
        <xsl:call-template name="nav-tree"/>
        <xsl:call-template name="content"/>
      </div>
    </xsl:template>

  <!-- Navigation -->
  <xsl:template name="nav-tree">
    <div id="aside" class="resizable-left border-right"><div id="left">
     <xsl:call-template name="header"/>

      <xsl:choose>
        <xsl:when test="Databases/Database">
          <ul class="tree">
            <li>
              <ul>
                <xsl:apply-templates select="Databases/Database"/>
              </ul>
            </li>
          </ul>
        </xsl:when>
        <xsl:otherwise>
          <strong> Error: </strong> documentations not found.
        </xsl:otherwise>
      </xsl:choose>
    </div></div>
  </xsl:template>

  <!-- Navigation - folders -->
  <xsl:template match="Modules|Functions|Procedures|Tables|Views">
    <xsl:variable name="class">
      <xsl:choose>
        <xsl:when test="*"> expand </xsl:when>
      </xsl:choose>
    </xsl:variable>

    <li class="{$class}">
      <i class="icon-folder"></i>
      <a class="ajax" data-target="#right" href="#{@src}{$ext}"><xsl:value-of select="local-name()"/></a>
      <ul style="display: none;">
        <xsl:apply-templates select="*"/>
      </ul>
    </li>
  </xsl:template>

  <!-- Navigation - objects -->
  <xsl:template match="Database|Module|Function|Procedure|Table|View">
    <xsl:variable name="class">
      <xsl:choose>
        <xsl:when test="*"> expand </xsl:when>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="icon">
      <xsl:choose>
        <xsl:when test="local-name() = 'Database'"> icon-database </xsl:when>
        <xsl:when test="local-name() = 'Module'"> icon-module </xsl:when>
        <xsl:when test="local-name() = 'Function'"> icon-function </xsl:when>
        <xsl:when test="local-name() = 'Procedure'"> icon-procedure </xsl:when>
        <xsl:when test="local-name() = 'Table'"> icon-table </xsl:when>
        <xsl:when test="local-name() = 'View'"> icon-view </xsl:when>
      </xsl:choose>
    </xsl:variable>

    <li class="{$class}">
      <i class="{$icon}"></i>
      <a class="ajax" data-target="#right" href="#{@src}{$ext}"><xsl:value-of select="@name"/></a>
      <ul style="display: none;">
        <xsl:apply-templates select="*"/>
      </ul>
    </li>
  </xsl:template>

  <!-- Content -->
  <xsl:template name="content">
    <div id="content" class="resizable-right">
      <div id="right"></div>
      <xsl:call-template name="documentations-list"/>
      <xsl:call-template name="footer"/>
    </div>
  </xsl:template>

  <xsl:template name="documentations-list">
    <div data-page="index{$ext}">
      <xsl:apply-templates select="Breadcrumbs"/>

      <h1> Repository </h1>
      <ol type="1">
        <xsl:for-each select="Databases/Database">
          <li>
            <a href="#{@src}{$ext}" class="ajax" data-target="#right">
              <xsl:value-of select="@name"/>
            </a>
          </li>
        </xsl:for-each>
      </ol>
    </div>
  </xsl:template>

    <!-- Footer -->
    <xsl:template name="footer">
      <footer class="footer font-gray font-small cf">
        <xsl:if test="/DataDocumenter/Edition">
          <span style="float: left">
               <xsl:value-of select="/DataDocumenter/Edition"/>
          </span>
        </xsl:if>
        <span style="float:right"> Generated with <strong><a href="{Global/Product/@src}"><xsl:value-of select="Global/Product"/></a></strong></span>
      </footer>
    </xsl:template>

    <!-- Extra scripts -->
    <xsl:template name="scripts">
      <div id="popup-error"> Action cannot be finished </div>
      <div id="binding"></div>

      <!--[if lt IE 9]>
      <script src="http://ie7-js.googlecode.com/svn/version/2.1(beta4)/IE9.js"></script>
      <![endif]-->
      <script src="{$resources}lib/jQuery/jquery-1.11.3.min.js"></script>
      <script src="{$resources}lib/jQueryUI/jquery-ui-1.9.2.custom.min.js"></script>
      <script src="{$resources}lib/iframeResizer/client.min.js"></script>
      <script src="{$resources}lib/Store.js/store.legacy.min.js"></script>
      <script src="{$resources}js/tables.js"></script>
      <script src="{$resources}js/loader.single.js"></script>
      <script src="{$resources}js/treeExpand.js"></script>
      <script src="{$resources}js/utilities.js"></script>
      <script src="{$resources}js/mobile.js"></script>
      <script src="{$resources}js/dependenciesTree.js"></script>
    </xsl:template>

</xsl:stylesheet>